@@ -36,6 +36,7 @@ using MonoDevelop.Core;
 using MonoDevelop.Core.Execution;
 using MonoDevelop.Core.ProgressMonitoring;
 using MonoDevelop.Projects;
+using Mono.Addins;
 
 namespace JavaBinding
 {
@@ -56,7 +57,7 @@ namespace JavaBinding
 			return result.ToString ();
 		}
 		
-		public static BuildResult Compile (ProjectItemCollection projectItems, DotNetProjectConfiguration configuration, IProgressMonitor monitor)
+		public static BuildResult Compile (ProjectItemCollection projectItems, DotNetProjectConfiguration configuration, ConfigurationSelector configurationSelector, IProgressMonitor monitor)
 		{
 			JavaCompilerParameters parameters = (configuration.CompilationParameters as JavaCompilerParameters) ?? new JavaCompilerParameters ();
 			string outdir   = configuration.OutputDirectory;
@@ -75,8 +76,8 @@ namespace JavaBinding
 			}
 
 			StringBuilder classpath = new StringBuilder (parameters.ClassPath);
-			AppendClasspath (classpath, GenerateReferenceStubs (monitor, configuration, parameters, projectItems));
-			AppendClasspath (classpath, GenerateReferenceStub (monitor, configuration, new ProjectReference(ReferenceType.Gac, "mscorlib")));
+			AppendClasspath (classpath, GenerateReferenceStubs (monitor, configurationSelector, configuration, parameters, projectItems));
+			AppendClasspath (classpath, GenerateReferenceStub (monitor, configurationSelector, configuration, new ProjectReference(ReferenceType.Gac, "mscorlib")));
 			
 			StringBuilder args = new StringBuilder ();
 			args.Append (options.ToString ());
@@ -93,9 +94,17 @@ namespace JavaBinding
 			CompilerResults results = new CompilerResults (new TempFileCollection ());
 			StringWriter output = new StringWriter ();
 			StringWriter error = new StringWriter ();
-			
-			bool success = Compile (monitor, compiler, args.ToString (), configuration, parameters, output, error);
-			ParseJavaOutput (parameters.Compiler, error.ToString(), results);
+
+			bool success;
+			try {
+				success = Compile (monitor, compiler, args.ToString (), configuration, parameters, output, error);
+				ParseJavaOutput (parameters.Compiler, error.ToString(), results);
+			} catch (Exception ex) {
+				string errorMsg = AddinManager.CurrentLocalizer.GetString ("Execution on '{0}' failed. Make sure the Java compiler is properly installed", compiler);
+				monitor.ReportError (errorMsg, ex);
+				success = false;
+				results.Errors.Add (new CompilerError ("", 0, 0, "", errorMsg));
+			}
 			
 			if (success) {
 				output = new StringWriter ();
@@ -114,23 +123,24 @@ namespace JavaBinding
 			path.Append (jar);
 		}
 		
-		static string GenerateReferenceStubs (IProgressMonitor monitor, DotNetProjectConfiguration configuration, JavaCompilerParameters compilerparameters, ProjectItemCollection projectItems)
+		static string GenerateReferenceStubs (IProgressMonitor monitor, ConfigurationSelector configurationSelector, DotNetProjectConfiguration configuration, JavaCompilerParameters compilerparameters, ProjectItemCollection projectItems)
 		{
 			StringBuilder result = new StringBuilder ();
 			foreach (ProjectReference reference in projectItems.GetAll<ProjectReference> ()) {
-				AppendClasspath (result, GenerateReferenceStub (monitor, configuration, reference));
+				AppendClasspath (result, GenerateReferenceStub (monitor, configurationSelector, configuration, reference));
 			}
 			return result.ToString ();
 		}
 		
-		static string GenerateReferenceStub (IProgressMonitor monitor,DotNetProjectConfiguration configuration, ProjectReference reference)
+		static string GenerateReferenceStub (IProgressMonitor monitor, ConfigurationSelector configurationSelector, DotNetProjectConfiguration configuration, ProjectReference reference)
 		{
 			StringBuilder result = new StringBuilder ();
-			foreach (string fileName in reference.GetReferencedFileNames (configuration.Id)) {
+			foreach (string fileName in reference.GetReferencedFileNames (configurationSelector)) {
 				string name = Path.GetFileNameWithoutExtension (Path.GetFileName (fileName));
 				string outputName = Path.Combine (configuration.OutputDirectory, name + ".jar");
 				if (!System.IO.File.Exists (outputName)) {
 					monitor.Log.WriteLine (String.Format (GettextCatalog.GetString ("Generating {0} reference stub ..."), name));
+					monitor.Log.WriteLine ("ikvmstub \"" + fileName + "\"");
 					ProcessWrapper p = Runtime.ProcessService.StartProcess ("ikvmstub", "\"" + fileName + "\"", configuration.OutputDirectory, monitor.Log, monitor.Log, null);
 					p.WaitForExit ();
 					if (p.ExitCode != 0) {
@@ -184,15 +194,16 @@ namespace JavaBinding
 			args.Append (" -srcpath:"); args.Append (configuration.ParentItem.BaseDirectory);
 			
 			foreach (ProjectReference lib in projectItems.GetAll<ProjectReference> ()) {
-				foreach (string fileName in lib.GetReferencedFileNames (configuration.Id)) {
+				foreach (string fileName in lib.GetReferencedFileNames (configuration.Selector)) {
 					args.Append (" -r:"); args.Append (fileName);
 				}
 			}
 			
-			foreach (string fileName in new ProjectReference(ReferenceType.Gac, "mscorlib").GetReferencedFileNames (configuration.Id)) {
+			foreach (string fileName in new ProjectReference(ReferenceType.Gac, "mscorlib").GetReferencedFileNames (configuration.Selector)) {
 				args.Append (" -r:"); args.Append (fileName);
 			}
 			
+			monitor.Log.WriteLine ("ikvmc " + args);
 			Process process = Runtime.ProcessService.StartProcess ("ikvmc", args.ToString (), configuration.OutputDirectory, chainedOutput, chainedError, null);
 			process.WaitForExit ();
 		}
@@ -208,6 +219,7 @@ namespace JavaBinding
 			chainedOutput.ChainWriter (output);
 			
 			monitor.Log.WriteLine (GettextCatalog.GetString ("Compiling Java source code ..."));
+			monitor.Log.WriteLine (compiler + " " + args);
 			
 			Process process = Runtime.ProcessService.StartProcess (compiler, args, null, chainedOutput, chainedError, null);
 			process.WaitForExit ();
