@@ -53,15 +53,19 @@ namespace JavaBinding
 				return LanguageName;
 			}
 		}
-		
+		public string ProjectStockIcon {
+			get {
+				return "md-project";
+			}
+		}
 		public bool IsSourceCodeFile (string fileName)
 		{
 			return Path.GetExtension (fileName) == ".java";
 		}
 		
-		public BuildResult Compile (ProjectItemCollection projectItems, DotNetProjectConfiguration configuration, IProgressMonitor monitor)
+		public BuildResult Compile (ProjectItemCollection projectItems, DotNetProjectConfiguration configuration, ConfigurationSelector configurationSelector,  IProgressMonitor monitor)
 		{
-			return IKVMCompilerManager.Compile (projectItems, configuration, monitor);
+			return IKVMCompilerManager.Compile (projectItems, configuration, configurationSelector, monitor);
 		}
 		
 		public ConfigurationParameters CreateCompilationParameters (XmlElement projectOptions)
@@ -89,11 +93,9 @@ namespace JavaBinding
 			return null;
 		}
 		
-		// http://www.nbirn.net/Resources/Developers/Conventions/Commenting/Java_Comments.htm#CommentBlock
-		public string CommentTag
-		{
-			get { return "//"; }
-		}
+		public string SingleLineCommentTag { get { return "//"; } }
+		public string BlockCommentStartTag { get { return "/*"; } }
+		public string BlockCommentEndTag { get { return "*/"; } }
 		
 		public CodeDomProvider GetCodeDomProvider ()
 		{
@@ -115,7 +117,7 @@ namespace JavaBinding
 		
 		public ClrVersion[] GetSupportedClrVersions ()
 		{
-			return new ClrVersion[] { ClrVersion.Net_1_1 };
+			return new ClrVersion[] { ClrVersion.Net_2_0 };
 		}
 	}
 	
